aboutsummaryrefslogtreecommitdiffstats
path: root/ui/cli/tap-icmpv6stat.c
diff options
context:
space:
mode:
Diffstat (limited to 'ui/cli/tap-icmpv6stat.c')
-rw-r--r--ui/cli/tap-icmpv6stat.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/ui/cli/tap-icmpv6stat.c b/ui/cli/tap-icmpv6stat.c
index 04bcf973a8..517b704148 100644
--- a/ui/cli/tap-icmpv6stat.c
+++ b/ui/cli/tap-icmpv6stat.c
@@ -103,10 +103,10 @@ static gint compare_doubles(gconstpointer a, gconstpointer b)
* "icmpv6" tap, the third parameter type is icmp_transaction_t.
*
* function returns :
* FALSE: no updates, no need to call (*draw) later
* TRUE: state has changed, call (*draw) sometime later
*/
-static gboolean
+static tap_packet_status
icmpv6stat_packet(void *tapdata, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *data)
{
icmpv6stat_t *icmpv6stat = (icmpv6stat_t *)tapdata;
@@ -114,13 +114,13 @@ icmpv6stat_packet(void *tapdata, packet_info *pinfo _U_, epan_dissect_t *edt _U_
double resp_time, *rt;
if (trans == NULL)
- return FALSE;
+ return TAP_PACKET_DONT_REDRAW;
if (trans->resp_frame) {
resp_time = nstime_to_msec(&trans->resp_time);
rt = g_new(double, 1);
if (rt == NULL)
- return FALSE;
+ return TAP_PACKET_DONT_REDRAW;
*rt = resp_time;
icmpv6stat->rt_list = g_slist_prepend(icmpv6stat->rt_list, rt);
icmpv6stat->num_resps++;
@@ -136,9 +136,9 @@ icmpv6stat_packet(void *tapdata, packet_info *pinfo _U_, epan_dissect_t *edt _U_
} else if (trans->rqst_frame)
icmpv6stat->num_rqsts++;
else
- return FALSE;
+ return TAP_PACKET_DONT_REDRAW;
- return TRUE;
+ return TAP_PACKET_REDRAW;
}
@@ -103,10 +103,10 @@ static gint compare_doubles(gconstpointer a, gconstpointer b)
*
* function returns :
- * FALSE: no updates, no need to call (*draw) later
- * TRUE: state has changed, call (*draw) sometime later
+ * TAP_PACKET_DONT_REDRAW: no updates, no need to call (*draw) later
+ * TAP_PACKET_REDRAW: state has changed, call (*draw) sometime later
*/